package com.ruoyi.web.controller.pc;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import com.ruoyi.system.domain.req.PcTDoctorQueryByPageReq;
import com.ruoyi.system.domain.req.PcTDoctorUpdateReq;
import com.ruoyi.system.domain.resp.PcTDoctorQueryByPageResp;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.system.domain.TDoctor;
import com.ruoyi.system.service.ITDoctorService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 医生信息Controller
 * 
 * @author ruoyi
 * @date 2022-08-03
 */
@Api("pc-医生列表")
@RestController
@RequestMapping("/system/doctorpc")
public class TDoctorController extends BaseController
{
    @Autowired
    private ITDoctorService tDoctorService;

    /**
     * 查询医生信息列表
     */
    @ApiOperation("查询医生信息列表")
    @PostMapping("/queryByPage")
    @Log(title = "PC查询医生信息列表", businessType = BusinessType.OTHER)
    public TableDataInfo queryByPage(@RequestBody @Validated PcTDoctorQueryByPageReq pcTDoctorQueryByPageReq)
    {
        startPage();
        List<PcTDoctorQueryByPageResp> list = tDoctorService.queryByPage(pcTDoctorQueryByPageReq);
        return getDataTable(list);
    }

    /**
     * 导出医生信息列表
     */
    @ApiOperation("导出医生信息列表")
    @Log(title = "导出医生信息列表", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, @RequestBody @Validated PcTDoctorQueryByPageReq pcTDoctorQueryByPageReq)
    {
//        List<TDoctor> list = tDoctorService.selectTDoctorList(tDoctor);
        startPage();
        List<PcTDoctorQueryByPageResp> list = tDoctorService.queryByPage(pcTDoctorQueryByPageReq);
        ExcelUtil<PcTDoctorQueryByPageResp> util = new ExcelUtil<PcTDoctorQueryByPageResp>(PcTDoctorQueryByPageResp.class);
        util.exportExcel(response, list, "医生信息数据");
    }

    /**
     * 获取医生信息详细信息
     */
    @ApiOperation("获取医生信息详细信息")
    @GetMapping(value = "/queryById/{id}")
    @Log(title = "PC获取医生信息详细信息", businessType = BusinessType.OTHER)
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return AjaxResult.success(tDoctorService.selectTDoctorById(id));
    }

    /**
     * 修改医生信息
     */
    @ApiOperation("修改医生信息")
    @Log(title = "修改医生信息", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody @Validated PcTDoctorUpdateReq pcTDoctorUpdateReq)
    {
        TDoctor tDoctor = new TDoctor();
        BeanUtils.copyProperties(pcTDoctorUpdateReq,tDoctor);
        return toAjax(tDoctorService.updateTDoctor(tDoctor));
    }

    /**
     * 删除医生信息
     */
    @ApiOperation("删除医生信息")
    @Log(title = "医生信息", businessType = BusinessType.DELETE)
	@DeleteMapping("/deleteById/{id}")
    public AjaxResult remove(@PathVariable("id") Long id)
    {
        return toAjax(tDoctorService.deleteTDoctorById(id));
    }
}
